@@ -4,7 +4,7 @@
 #
 # Pentaho Data Integration
 #
-# Copyright (C) 2006-2017 by Hitachi Vantara : http://www.pentaho.com
+# Copyright (C) 2006-2018 by Hitachi Vantara : http://www.pentaho.com
 #
 # *****************************************************************************
 #
@@ -22,6 +22,14 @@
 #
 # *****************************************************************************
 
+# OS specific support.
+darwin=false;
+case "$(uname -s)" in
+  Darwin*)
+    darwin=true
+    ;;
+esac
+
 BASEDIR="`dirname $0`"
 cd "$BASEDIR"
 DIR="`pwd`"
@@ -31,5 +39,8 @@ if [ ! "x$JAAS_LOGIN_MODULE_CONFIG" = "x" -a ! "x$JAAS_LOGIN_MODULE_NAME" = "x"
 	OPT=$OPT" -Djava.security.auth.login.config=$JAAS_LOGIN_MODULE_CONFIG"
 	OPT=$OPT" -Dloginmodulename=$JAAS_LOGIN_MODULE_NAME"
 fi
+if [ "${darwin}" = "true" ]; then
+  OPT="$OPT -Djava.awt.headless=true"
+fi
 export OPT
 "$DIR/spoon.sh" -main org.pentaho.di.www.Carte "$@"
