@@ -4,7 +4,7 @@
 #
 # Pentaho Data Integration
 #
-# Copyright (C) 2005-2017 by Hitachi Vantara : http://www.pentaho.com
+# Copyright (C) 2005-2018 by Hitachi Vantara : http://www.pentaho.com
 #
 # *****************************************************************************
 #
@@ -64,7 +64,7 @@ setPentahoEnv
 # **************************************************
 
 LIBPATH="NONE"
-STARTUP="$BASEDIR/launcher/pentaho-application-launcher-8.0.0.0-28.jar"
+STARTUP="$BASEDIR/launcher/launcher.jar"
 
 if [ -z "$IS_YARN" ]; then
 	# Go to directory where spoon.sh located
@@ -139,6 +139,7 @@ case `uname -s` in
 
             HASWEBKITGTK=`ldconfig -p | grep webkitgtk-1.0`
             export LIBWEBKITGTK="$HASWEBKITGTK"
+            export JavaScriptCoreUseJIT=0
             if [ -z "$HASWEBKITGTK" ]; then
               echo "#######################################################################"
               echo "WARNING:  no libwebkitgtk-1.0 detected, some features will be unavailable"
